@@ -221,7 +221,9 @@ class OC_Helper {
 
 			foreach ($files as $fileInfo) {
 				/** @var SplFileInfo $fileInfo */
-				if ($fileInfo->isDir()) {
+				if ($fileInfo->isLink()) {
+					unlink($fileInfo->getPathname());
+				} else if ($fileInfo->isDir()) {
 					rmdir($fileInfo->getRealPath());
 				} else {
 					unlink($fileInfo->getRealPath());
@@ -500,7 +502,7 @@ class OC_Helper {
 	 */
 	public static function freeSpace($dir) {
 		$freeSpace = \OC\Files\Filesystem::free_space($dir);
-		if ($freeSpace !== \OCP\Files\FileInfo::SPACE_UNKNOWN) {
+		if ($freeSpace < \OCP\Files\FileInfo::SPACE_UNLIMITED) {
 			$freeSpace = max($freeSpace, 0);
 			return $freeSpace;
 		} else {
