@@ -322,10 +322,30 @@ class Checker {
 		$x509 = new \phpseclib\File\X509();
 		$rootCertificatePublicKey = $this->fileAccessHelper->file_get_contents($this->environmentHelper->getServerRoot().'/resources/codesigning/root.crt');
 		$x509->loadCA($rootCertificatePublicKey);
-		$x509->loadX509($certificate);
+		$loadedCertificate = $x509->loadX509($certificate);
 		if(!$x509->validateSignature()) {
-			throw new InvalidSignatureException('Certificate is not valid.');
+			throw new InvalidSignatureException('App Certificate is not valid.');
 		}
+
+		// Check if the certificate has been revoked
+		$crlFileContent = $this->fileAccessHelper->file_get_contents($this->environmentHelper->getServerRoot().'/resources/codesigning/intermediate.crl.pem');
+		if ($crlFileContent && strlen($crlFileContent) > 0) {
+			$crl = new \phpseclib\File\X509();
+			$crl->loadCA($rootCertificatePublicKey);
+			$crl->loadCRL($crlFileContent);
+			if(!$crl->validateSignature()) {
+				throw new InvalidSignatureException('Certificate Revocation List is not valid.');
+			}
+			// Get the certificate's serial number.
+			$csn = $loadedCertificate['tbsCertificate']['serialNumber']->toString();
+
+			// Check certificate revocation status.
+			$revoked = $crl->getRevoked($csn);
+			if ($revoked) {
+				throw new InvalidSignatureException('Certificate has been revoked.');
+			}
+		}
+
 		// Verify if certificate has proper CN. "core" CN is always trusted.
 		if($x509->getDN(X509::DN_OPENSSL)['CN'] !== $certificateCN && $x509->getDN(X509::DN_OPENSSL)['CN'] !== 'core') {
 			throw new InvalidSignatureException(
@@ -342,6 +362,19 @@ class Checker {
 			throw new InvalidSignatureException('Signature could not get verified.');
 		}
 
+		// Fixes for the updater as shipped with ownCloud 9.0.x: The updater is
+		// replaced after the code integrity check is performed.
+		//
+		// Due to this reason we exclude the whole updater/ folder from the code
+		// integrity check.
+		if($basePath === $this->environmentHelper->getServerRoot()) {
+			foreach($expectedHashes as $fileName => $hash) {
+				if(strpos($fileName, 'updater/') === 0) {
+					unset($expectedHashes[$fileName]);
+				}
+			}
+		}
+
 		// Compare the list of files which are not identical
 		$currentInstanceHashes = $this->generateHashes($this->getFolderIterator($basePath), $basePath);
 		$differencesA = array_diff($expectedHashes, $currentInstanceHashes);
